@@ -24,12 +24,13 @@ extensions = [
         'sphinx.ext.autosummary',
         'sphinx.ext.viewcode',
         'sphinx.ext.intersphinx',
+        'sphinx.ext.napoleon',
         'sphinx_rtd_theme',
 ]
 intersphinx_mapping = {
         'python': ('https://docs.python.org/3', None),
 }
-autosummary_generate = True
+autosummary_generate = False
 autodoc_default_options = {
         'exclude-members': '__dict__,__weakref__,__module__',
 }
